@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -369,9 +369,15 @@ void Favorites::jump() {
 	qDebug("Favorites::jump");
 
 	bool ok;
+	#if QT_VERSION >= 0x050000
+	int item = QInputDialog::getInt(parent_widget, tr("Jump to item"),
+                          tr("Enter the number of the item in the list to jump:"), 
+                          last_item, 1, f_list.count(), 1, &ok);
+	#else
 	int item = QInputDialog::getInteger(parent_widget, tr("Jump to item"),
                           tr("Enter the number of the item in the list to jump:"), 
                           last_item, 1, f_list.count(), 1, &ok);
+	#endif
 	if (ok) {
 		last_item = item;
 		item--;
