@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -57,6 +57,10 @@ MyAction::MyAction(QKeySequence accel, QObject * parent, const char * name,
 MyAction::~MyAction() {
 }
 
+void MyAction::addShortcut(QKeySequence key) {
+	setShortcuts( shortcuts() << key);
+}
+
 void MyAction::addActionToParent() {
 	if (parent()) {
 		if (parent()->inherits("QWidget")) {
