@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@
 #include <QHeaderView>
 #include <QTextCodec>
 #include <QApplication>
+#include <QMimeData>
 
 #include "mytablewidget.h"
 #include "myaction.h"
@@ -153,8 +154,14 @@ void Playlist::createTable() {
 	listView->setShowGrid(false);
 	listView->setSortingEnabled(false);
 	//listView->setAlternatingRowColors(true);
+
+#if QT_VERSION >= 0x050000
+	listView->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
+	listView->horizontalHeader()->setSectionResizeMode(COL_NAME, QHeaderView::Stretch);
+#else
 	listView->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
 	listView->horizontalHeader()->setResizeMode(COL_NAME, QHeaderView::Stretch);
+#endif
 	/*
 	listView->horizontalHeader()->setResizeMode(COL_TIME, QHeaderView::ResizeToContents);
 	listView->horizontalHeader()->setResizeMode(COL_PLAY, QHeaderView::ResizeToContents);
@@ -395,7 +402,7 @@ void Playlist::setCurrentItem(int current) {
 	current_item = current;
 
 	if ((current_item > -1) && (current_item < pl.count())) {
-		pl[current_item].setPlayed(TRUE);
+		pl[current_item].setPlayed(true);
 	}
 
 	if ( (old_current >= 0) && (old_current < listView->rowCount()) ) {
@@ -471,7 +478,7 @@ void Playlist::addItem(QString filename, QString name, double duration) {
 			// Let's see if it looks like a file (no dvd://1 or something)
 			if (filename.indexOf(QRegExp("^.*://.*")) == -1) {
 				// Local file
-				name = fi.fileName(); //fi.baseName(TRUE);
+				name = fi.fileName(); //fi.baseName(true);
 			} else {
 				// Stream
 				name = filename;
@@ -909,7 +916,7 @@ void Playlist::playItem( int n ) {
 	QString filename_with_path = playlist_path + "/" + filename;
 
 	if (!filename.isEmpty()) {
-		//pl[n].setPlayed(TRUE);
+		//pl[n].setPlayed(true);
 		setCurrentItem(n);
 		if (play_files_from_start) 
 			core->open(filename, 0);
@@ -951,6 +958,14 @@ void Playlist::playPrev() {
 	}
 }
 
+
+void Playlist::resumePlay() {
+	if (pl.count() > 0) {
+		if (current_item < 0) current_item = 0;
+		playItem(current_item);
+	}
+}
+
 void Playlist::getMediaInfo() {
 	qDebug("Playlist:: getMediaInfo");
 
@@ -1137,7 +1152,7 @@ void Playlist::removeSelected() {
 	for (int n=0; n < listView->rowCount(); n++) {
 		if (listView->isSelected(n, 0)) {
 			qDebug(" row %d selected", n);
-			pl[n].setMarkForDeletion(TRUE);
+			pl[n].setMarkForDeletion(true);
 			number_previous_item++;
 			if (first_selected == -1) first_selected = n;
 		}
@@ -1183,7 +1198,7 @@ void Playlist::removeAll() {
 void Playlist::clearPlayedTag() {
 	PlaylistItemList::iterator it;
 	for ( it = pl.begin(); it != pl.end(); ++it ) {
-		(*it).setPlayed(FALSE);
+		(*it).setPlayed(false);
 	}
 	updateView();
 }
@@ -1328,6 +1343,9 @@ void Playlist::dropEvent( QDropEvent *e ) {
 		}
 	}
 
+	#ifdef Q_OS_WIN
+	files = Helper::resolveSymlinks(files); // Check for Windows shortcuts
+	#endif
 
 	QStringList only_files;
 	for (int n = 0; n < files.count(); n++) {
