@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,10 +28,10 @@ class PlaylistItem {
 
 public:
 	PlaylistItem() { _filename=""; _name=""; _duration=0; 
-                     _played = FALSE; _deleted=FALSE; };
+                     _played = false; _deleted=false; };
 	PlaylistItem(QString filename, QString name, double duration) {
 		         _filename = filename; _name = name; _duration = duration; 
-                 _played = FALSE; _deleted = FALSE; };
+                 _played = false; _deleted = false; };
 	~PlaylistItem() {};
 
 	void setFilename(QString filename) { _filename = filename; };
@@ -91,6 +91,8 @@ public slots:
 	virtual void playNext();
 	virtual void playPrev();
 
+	virtual void resumePlay();
+
 	virtual void removeSelected();
 	virtual void removeAll();
 	virtual void remove(int);
