@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -111,11 +111,14 @@ protected:
 	bool startInFullscreen();
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
-	void setAvoidScreensaver(bool b);
-	bool avoidScreensaver();
-	
+	#ifdef SCREENSAVER_OFF
 	void setTurnScreensaverOff(bool b);
 	bool turnScreensaverOff();
+	#endif
+	#ifdef AVOID_SCREENSAVER
+	void setAvoidScreensaver(bool b);
+	bool avoidScreensaver();
+	#endif
 #else
 	void setDisableScreensaver(bool b);
 	bool disableScreensaver();
