@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 TimeSlider::TimeSlider( QWidget * parent ) : MySlider(parent)
 {
-	dont_update = FALSE;
+	dont_update = false;
 	setMinimum(0);
 #ifdef SEEKBAR_RESOLUTION
 	setMaximum(SEEKBAR_RESOLUTION);
@@ -57,14 +57,14 @@ void TimeSlider::stopUpdate() {
 	#if DEBUG
 	qDebug("TimeSlider::stopUpdate");
 	#endif
-	dont_update = TRUE;
+	dont_update = true;
 }
 
 void TimeSlider::resumeUpdate() {
 	#if DEBUG
 	qDebug("TimeSlider::resumeUpdate");
 	#endif
-	dont_update = FALSE;
+	dont_update = false;
 }
 
 void TimeSlider::mouseReleased() {
@@ -138,9 +138,10 @@ int TimeSlider::pos() {
 	return position;
 }
 
+/*
 void TimeSlider::wheelEvent( QWheelEvent * e ) {
 	e->ignore();
 }
-
+*/
 
 #include "moc_timeslider.cpp"
