@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -131,7 +131,7 @@ VideoPreview::~VideoPreview() {
 }
 
 void VideoPreview::retranslateStrings() {
-	progress->setWindowTitle(tr("Video preview"));
+	progress->setWindowTitle(tr("Thumbnail Generator"));
 	progress->setCancelButtonText( tr("Cancel") );
 
 	foot->setText("<i>"+ tr("Generated by SMPlayer") +" </i>");
@@ -142,7 +142,7 @@ void VideoPreview::setMplayerPath(QString mplayer_path) {
 	QFileInfo fi(mplayer_bin);
 	if (fi.exists() && fi.isExecutable() && !fi.isDir()) {
 		mplayer_bin = fi.absoluteFilePath();
-    }
+	}
 
 	qDebug("VideoPreview::setMplayerPath: mplayer_bin: '%s'", mplayer_bin.toUtf8().constData());
 }
@@ -491,8 +491,8 @@ VideoInfo VideoPreview::getInfo(const QString & mplayer_path, const QString & fi
 
 void VideoPreview::showInfo(bool visible) {
 	qDebug("VideoPreview::showInfo: %d", visible);
-	info->setShown(visible);
-	foot->setShown(visible);
+	info->setVisible(visible);
+	foot->setVisible(visible);
 }
 
 void VideoPreview::saveImage() {
